# This file is generated by scikitplot's build process
# It contains CITATION.bib results at the time of building this package.
import pathlib
from scikitplot._log import get_logger
log = get_logger(__name__)

CITATION = """% ---------------------------------------------------------
% CITATION.bib file for scikit-plots
% This file provides citation information for users
% who want to cite the library, related papers, and books.
% ---------------------------------------------------------

@misc{scikit-plots:vlatest,
  author = { scikit-plots developers },
  title  = { scikit-plots: Machine Learning Visualization in Python },
  year   = { 2024 },
  version = { latest },
  url    = { https://scikit-plots.github.io },
  note   = { Scikit-plot is the result of an unartistic data scientist's dreadful realization that visualization is one of the most crucial components in the data science process, not just a mere afterthought. },
  doi    = { 10.5281/zenodo.13367000 }
}"""

# Set the bibtex entry to the article referenced in CITATION.
def _get_bibtex():
    _bibtex = ''
    try:
        # Attempt to read the CITATION.bib file
        refs = (pathlib.Path(__file__).parent / "../CITATION.bib").read_text().split("@misc")[1:][0]
        _bibtex = f"@misc{refs}" if refs else ""
        log.debug("_bibtex from file CITATION.bib")
    except FileNotFoundError:
        # If CITATION.bib file is not found, fall back to the defined CITATION string
        refs = CITATION.split("@misc")[1:][0]
        _bibtex = f"@misc{refs}" if refs else ""
        log.debug("_bibtex from attr CITATION")
    except Exception as e:
        # Handle any unexpected errors
        log.error(f"Unexpected error while reading CITATION.bib: {e}")
    return _bibtex